@@ -30,7 +30,8 @@ import os, sys, json, re
 import dxpy
 from .describe import get_ls_l_desc
 from ..exceptions import DXError
-from ..compat import str, input, get_env_var
+from ..compat import str, input
+from ..utils.env import get_env_var
 
 def pick(choices, default=None, str_choices=None, prompt=None, allow_mult=False, more_choices=False):
     '''
